# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class VolumeLifeCycleSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'grace_period_days': 'int',
        'grace_period_end_action': 'GracePeriodEndAction'
    }

    attribute_map = {
        'grace_period_days': 'gracePeriodDays',
        'grace_period_end_action': 'gracePeriodEndAction'
    }

    def __init__(self, grace_period_days=None, grace_period_end_action=None, local_vars_configuration=None):  # noqa: E501
        """VolumeLifeCycleSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._grace_period_days = None
        self._grace_period_end_action = None
        self.discriminator = None

        if grace_period_days is not None:
            self.grace_period_days = grace_period_days
        if grace_period_end_action is not None:
            self.grace_period_end_action = grace_period_end_action

    @property
    def grace_period_days(self):
        """Gets the grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501

        Number of days before the files associated to this volume expires  # noqa: E501

        :return: The grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501
        :rtype: int
        """
        return self._grace_period_days

    @grace_period_days.setter
    def grace_period_days(self, grace_period_days):
        """Sets the grace_period_days of this VolumeLifeCycleSettings.

        Number of days before the files associated to this volume expires  # noqa: E501

        :param grace_period_days: The grace_period_days of this VolumeLifeCycleSettings.  # noqa: E501
        :type: int
        """

        self._grace_period_days = grace_period_days

    @property
    def grace_period_end_action(self):
        """Gets the grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501


        :return: The grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501
        :rtype: GracePeriodEndAction
        """
        return self._grace_period_end_action

    @grace_period_end_action.setter
    def grace_period_end_action(self, grace_period_end_action):
        """Sets the grace_period_end_action of this VolumeLifeCycleSettings.


        :param grace_period_end_action: The grace_period_end_action of this VolumeLifeCycleSettings.  # noqa: E501
        :type: GracePeriodEndAction
        """

        self._grace_period_end_action = grace_period_end_action

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VolumeLifeCycleSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VolumeLifeCycleSettings):
            return True

        return self.to_dict() != other.to_dict()
