# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FileUploadCompleteRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'multipart_upload_id': 'str',
        'part_etags': 'list[PartEtag]'
    }

    attribute_map = {
        'multipart_upload_id': 'multipartUploadId',
        'part_etags': 'partEtags'
    }

    def __init__(self, multipart_upload_id=None, part_etags=None, local_vars_configuration=None):  # noqa: E501
        """FileUploadCompleteRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._multipart_upload_id = None
        self._part_etags = None
        self.discriminator = None

        if multipart_upload_id is not None:
            self.multipart_upload_id = multipart_upload_id
        if part_etags is not None:
            self.part_etags = part_etags

    @property
    def multipart_upload_id(self):
        """Gets the multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501

        The multipart upload id used by the object store  # noqa: E501

        :return: The multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501
        :rtype: str
        """
        return self._multipart_upload_id

    @multipart_upload_id.setter
    def multipart_upload_id(self, multipart_upload_id):
        """Sets the multipart_upload_id of this FileUploadCompleteRequest.

        The multipart upload id used by the object store  # noqa: E501

        :param multipart_upload_id: The multipart_upload_id of this FileUploadCompleteRequest.  # noqa: E501
        :type: str
        """

        self._multipart_upload_id = multipart_upload_id

    @property
    def part_etags(self):
        """Gets the part_etags of this FileUploadCompleteRequest.  # noqa: E501

        etags for each uploaded part (optional for files that uses multipart upload)  # noqa: E501

        :return: The part_etags of this FileUploadCompleteRequest.  # noqa: E501
        :rtype: list[PartEtag]
        """
        return self._part_etags

    @part_etags.setter
    def part_etags(self, part_etags):
        """Sets the part_etags of this FileUploadCompleteRequest.

        etags for each uploaded part (optional for files that uses multipart upload)  # noqa: E501

        :param part_etags: The part_etags of this FileUploadCompleteRequest.  # noqa: E501
        :type: list[PartEtag]
        """

        self._part_etags = part_etags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileUploadCompleteRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileUploadCompleteRequest):
            return True

        return self.to_dict() != other.to_dict()
