# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class PartInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'part': 'int',
        'date': 'str',
        'date_time': 'str',
        'signature': 'str'
    }

    attribute_map = {
        'part': 'part',
        'date': 'date',
        'date_time': 'dateTime',
        'signature': 'signature'
    }

    def __init__(self, part=None, date=None, date_time=None, signature=None, local_vars_configuration=None):  # noqa: E501
        """PartInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._part = None
        self._date = None
        self._date_time = None
        self._signature = None
        self.discriminator = None

        if part is not None:
            self.part = part
        if date is not None:
            self.date = date
        if date_time is not None:
            self.date_time = date_time
        if signature is not None:
            self.signature = signature

    @property
    def part(self):
        """Gets the part of this PartInfo.  # noqa: E501

        Part number to be applied to {part} in MultipartTemplate  # noqa: E501

        :return: The part of this PartInfo.  # noqa: E501
        :rtype: int
        """
        return self._part

    @part.setter
    def part(self, part):
        """Sets the part of this PartInfo.

        Part number to be applied to {part} in MultipartTemplate  # noqa: E501

        :param part: The part of this PartInfo.  # noqa: E501
        :type: int
        """

        self._part = part

    @property
    def date(self):
        """Gets the date of this PartInfo.  # noqa: E501

        Date to be applied to {date} in MultipartTemplate  # noqa: E501

        :return: The date of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this PartInfo.

        Date to be applied to {date} in MultipartTemplate  # noqa: E501

        :param date: The date of this PartInfo.  # noqa: E501
        :type: str
        """

        self._date = date

    @property
    def date_time(self):
        """Gets the date_time of this PartInfo.  # noqa: E501

        DateTime to be applied to {datetime} in MultipartTemplate  # noqa: E501

        :return: The date_time of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._date_time

    @date_time.setter
    def date_time(self, date_time):
        """Sets the date_time of this PartInfo.

        DateTime to be applied to {datetime} in MultipartTemplate  # noqa: E501

        :param date_time: The date_time of this PartInfo.  # noqa: E501
        :type: str
        """

        self._date_time = date_time

    @property
    def signature(self):
        """Gets the signature of this PartInfo.  # noqa: E501

        Signature to be applied to {signature} in MultipartTemplate  # noqa: E501

        :return: The signature of this PartInfo.  # noqa: E501
        :rtype: str
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """Sets the signature of this PartInfo.

        Signature to be applied to {signature} in MultipartTemplate  # noqa: E501

        :param signature: The signature of this PartInfo.  # noqa: E501
        :type: str
        """

        self._signature = signature

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PartInfo):
            return True

        return self.to_dict() != other.to_dict()
